      subroutine density_clear(rho, min_x, max_x, min_y, max_y, 
     +     den_min_x, den_max_x, f_z, l_z, density_map,
     +     map_min, map_max)

C     Generates final density map (density_map) from the calculated
C     density (rho). This routine is required because:
C
C     1. The dimensions of the final density map are not required to be
C     the same as those of the calculated density map.
C
C     2. Elements of the final density map further than den_max_x from
C     the origin are set to zero.
C
C     Hong Lin, 9/30/99 - original version
C     Yongchang Ji, 8/2000 - first modification
C     Yongchang Ji, 1/2002 - second modification
C     R Sinkovits, 7/10/06 - overhaul and cleanup

      implicit none

      integer, intent(in) :: min_x, max_x, min_y, max_y
      integer, intent(in) :: f_z, l_z, den_min_x, den_max_x
      real, intent(in)    :: rho(min_x:max_x, min_y:max_y, f_z:l_z)

      real, intent(out)   :: map_min, map_max
      real, intent(out)   :: density_map( den_min_x:den_max_x,
     +             den_min_x:den_max_x, f_z:l_z)

      integer col, row, sec, den_radius_sqr
      real    temp1, temp2
      real    background
      
      den_radius_sqr = den_max_x * den_max_x
      background = 0.0
      map_min =  huge(map_min)
      map_max = -huge(map_max)

      do sec = max(f_z, den_min_x), min(l_z, den_max_x)
         do row = den_min_x, den_max_x
            do col = den_min_x, den_max_x
               if ((sec*sec + row*row + col*col) .ge. den_radius_sqr
     +              .or. row .gt. max_x .or. row .lt. min_x 
     +              .or. col .gt. max_x .or. col .lt. min_x ) then
                  density_map(col,row,sec) = 0.
               else
                  temp1= rho(col,row,sec) - background
                  density_map(col,row,sec) = temp1
                  map_min = min(map_min,temp1)
                  map_max = max(map_max,temp1)
               endif
            enddo
         enddo
      enddo
            
      return
      end subroutine density_clear
