      subroutine move_data_2_slab(min_xyz, max_xyz, frst_RR, 
     +     lst_RR, frst_U, lst_U, F_VRU_TMP,
     +     min_x, max_x, rrnum, 
     +     num_x, num_y, F_XK_dZ )
C                                                            MOVE_DATA_2
C **********************************************************************
C * Subroutine: move_data_2_slab                                  *
C * Author: Robert E. Lynch (rel@cs.purdue.edu)                   *
C * Date:   1998                                                  *
C * Used in: rearrange_2_slab -- The the nearest outer subroutine *
C *                         allocating subsidiary buffers for     *
C *                         rearrange data for 1D Fourier         *
C *                         synthesis after global exchange       *
C * Function: move data to proper positions                       *
C * Usage:    call move_data_2_slab( min_xyz, max_xyz, frst_RR,   *
C *                  lst_RR, frst_U, lst_U, F_VRU_TMP,            *
C *                  min_x, max_x, rrnum,                         *
C *                  num_x, num_y, F_XK_dZ)                       *
C * Input:                                                        *
C *   min_xyz (Integer) -- The minimum index in X, Y and Z axes   *
C *                        of the real space.                     *
C *   max_xyz (Integer) -- The maximum index in X, Y and Z axes   *
C *                        of the real space.                     *
C *   min_x, max_x         (Integer) -- The                       *
C *     minimum and maximum indexes in X axis of the              *
C *     real space                                                *
C *   num_x, num_y (Integer) -- The number of X and Y indexes     *
C *   num_hkl (Integer) -- The number of coordinates in H, K or L *
C *                        axe of the reciprocal space.           *
C *   frst_RR, lst_RR (Integer) -- The first and last index of    *
C *                                RR                             *
C *   frst_U, lst_U (Integer) -- The first and last index of U    *
C *   F_VRU_TMP (Real) -- The exchanged result of 2D Fourier      *
C *                       synthesis for the current node to keep. *
C * Output:                                                       *
C *   F_XK_dZ                   (Real) -- The reorganized result  *
C *     of 2D Fourier synthesis for the current node to keep      *
C *                                                               *
C * Algorithm:                                                    *
C *   Move data from F_VRU_TMP to F_XK_dZ                         *
C *                                                               *
C * Modification history:                                         *
C *     - Hong Lin, Version 2.0, Oct. 1, 1999.                    *
C *       Correct errors in the main loop.                        *
C *       Add switch AVERAGING.                                   *
C *     - Hong Lin, Version 2.0, Dec.10, 1999.                    *
C *       Delete variable MAX_AXIS.                               *
C *   - Yongchang Ji, Final Version, Aug.2000 -- Jan. 2002        *
C *                                                               *
C *****************************************************************

      implicit none
      include '../include/allprogs.inc'
 
C     Subroutine arguments
      integer min_xyz, max_xyz, frst_RR, lst_RR, frst_U, lst_U,
     +     min_x, max_x, rrnum,
     +     num_x, num_y
  
      real   F_VRU_TMP( min_xyz:max_xyz, frst_RR:lst_RR, 
     +                  frst_U:lst_U )
      real   F_XK_dZ( min_x:max_x, 1:rrnum, frst_U:lst_U )

C     Local variables
      integer xxxx
      integer del_U

      xxxx = num_x * (-frst_RR + lst_RR + 1)

      do del_U = frst_U, lst_U
         call scopy( xxxx, F_VRU_TMP( min_x, frst_RR, del_U ), 1,
     +        F_XK_dZ( min_x, frst_RR, del_U ),       1 )
      enddo
      
      return
      end subroutine move_data_2_slab
