      subroutine calc_pfts_g (file, nview_mod, ncol, nrow, nrot, 
     1     nannuli, prj, prj_avg, pmap, xcen_model,
     2     ycen_model, pftrad_lo, pftrad_hi, del_ang, pfft, pfts,
     3     prjs, prjs_gold, compare_mode, idim1, idim2, bin, pi, radian)

C     Steps carried out by this routine (global mode only):                 
C     1. copy 2d projection from prjs_gold.                                
C     2. impose ctf on projection [compare_mode=1]                         
C     3. convert 2d cartesian projection map into 2d polar map.            
C     4. fourier transform the polar map.                                  
C     5. save polar fft in pfts array.                                     
C
C     Note that the following parameters in call to ctf_multiply have
C     been hardwired. These will NOT impose a decay factor on the data
c     mode=1; cc=0.0, beta=0.0, de=0.0, tfac = 0.0
C                                                                            
C     July 2002 Purdue University linux-intel, T. Baker/R. Ashmore.         
C
C     21-Jul-2006, Cleanup and modernization, replacement of
C     ctf_multiply with the more general ctf_scale (allows both
C     multiplication and division by the CTF). R. Sinkovits
      
      implicit none
      
      common/ctf_com/pixsiz, units, volts, amp_fac, focus_maj, 
     1 focus_min, ang_maj, cs_coeff

      integer*4, intent(in) :: nview_mod, ncol, nrow, nrot, nannuli
      integer*4, intent(in) :: compare_mode, idim1, idim2, file, bin
      real*4, intent(in)    :: del_ang, xcen_model, ycen_model
      real*4, intent(in)    :: pi, radian, pftrad_lo, pftrad_hi
      real*4, intent(in)    :: prjs_gold(ncol,nrow,nview_mod)

      real*4, intent(out) :: pmap(nrot,nannuli)
      real*4, intent(out) :: prj(ncol,nrow)
      real*4, intent(out) :: prjs(ncol,nrow,nview_mod)
      real*4, intent(out) :: prj_avg(ncol,nrow)
      real*4, intent(out) :: pfts((nrot/4),nannuli,nview_mod)
      real*4, intent(out) :: pfft(nrot*2,nannuli)

      integer*4 id, i, j, units(999)
      integer   alloc_stat
      real*4    pixsiz(999), volts(999), amp_fac(999), cs_coeff(999)
      real*4    focus_maj(999), focus_min(999), ang_maj(999)
      real*4    wavelength, wavel
      real*4    filt_fac(10)

      real*4, allocatable :: fft(:,:)
      
      allocate(fft(2*idim1,idim2), stat = alloc_stat)
      if(alloc_stat .gt. 0) then
         write(6,*) 'unable to allocate memory for fft in calc_pfts_g'
         call tsbend
      endif

      prj_avg = 0.0 ! f90 array syntax
      
      do id = 1,nview_mod

C     Obtain projection from prjs_gold array
         prj = prjs_gold(:,:,id) ! f90 array syntax

C     Apply CTF to projections if compare_mode equals 1
         if(compare_mode.eq.1) then
            call map_fft_fill (prj, ncol, nrow, fft, idim1, idim2, 0.0)
            call fft_2d (fft, idim1, idim2)
            wavelength = wavel (volts(file))
            call ctf_scale (1, 0, fft, idim1, idim2, units(file), 
     1           bin*pixsiz(file), pi, radian, wavelength,
     2           focus_maj(file), focus_min(file), ang_maj(file),
     3           amp_fac(file), cs_coeff(file), filt_fac, 0.0,
     4           .true., 0.0, 0.0, 0.0, volts(file))
            
            call fft_2d_back (fft, idim1, idim2)
            call fft_map_fill (fft, idim1, idim2, prj, ncol, nrow,
     1           0.0)
         endif
         
         prjs(:,:,id) = prj      ! f90 array syntax
         prj_avg = prj_avg + prj ! f90 array syntax

         call map_polar (prj, ncol, nrow, pmap, nrot, nannuli,
     1        xcen_model, ycen_model, pftrad_lo, pftrad_hi, del_ang)
         call pmap_fft (pmap, pfft, nrot, nannuli)
         
C     Store current 2d pfft in 3d pfts array
         do j = 1,nannuli
            do i = 1,(nrot/4)
               pfts(i,j,id) = sqrt (pfft(2*i-1,j)**2 + pfft(2*i,j)**2)
            enddo
         enddo

      enddo
      
      prj_avg = prj_avg/real(nview_mod) ! f90 array syntax
      call map_sym_cavg (prj_avg, ncol, nrow, xcen_model, ycen_model)

      deallocate(fft)

      return
      end subroutine calc_pfts_g
